package cn.com.infosec.jce.provider;

import cn.com.infosec.crypto.DataLengthException;
import cn.com.infosec.crypto.DerivationFunction;
import cn.com.infosec.crypto.DerivationParameters;
import cn.com.infosec.crypto.Digest;
import cn.com.infosec.crypto.params.KDFParameters;

public class BrokenKDF2BytesGenerator implements DerivationFunction {
   private Digest digest;
   private byte[] shared;
   private byte[] iv;

   public BrokenKDF2BytesGenerator(Digest digest) {
      this.digest = digest;
   }

   public void init(DerivationParameters param) {
      if (param instanceof KDFParameters) {
         BrokenKDF2BytesGenerator var10000 = this;
         KDFParameters var2;
         this.shared = (var2 = (KDFParameters)param).getSharedSecret();
         var10000.iv = var2.getIV();
      } else {
         throw new IllegalArgumentException("KDF parameters required for KDF2Generator");
      }
   }

   public Digest getDigest() {
      return this.digest;
   }

   public int generateBytes(byte[] out, int outOff, int len) {
      if (out.length - len >= outOff) {
         long var4;
         if ((var4 = (long)(len * 8)) > (long)(this.digest.getDigestSize() * 8) * 29L) {
            new IllegalArgumentException("Output length to large");
         }

         int var9 = (int)(var4 / (long)this.digest.getDigestSize());
         int var5;
         byte[] var6 = new byte[var5 = this.digest.getDigestSize()];

         for(int var7 = 1; var7 <= var9; ++var7) {
            byte[] var10009 = this.shared;
            this.digest.update(var10009, 0, var10009.length);
            this.digest.update((byte)(var7 & 255));
            this.digest.update((byte)(var7 >> 8 & 255));
            this.digest.update((byte)(var7 >> 16 & 255));
            this.digest.update((byte)(var7 >> 24 & 255));
            byte[] var10004 = this.iv;
            this.digest.update(var10004, 0, var10004.length);
            this.digest.doFinal(var6, 0);
            int var8;
            if ((var8 = len - outOff) > var5) {
               System.arraycopy(var6, 0, out, outOff, var5);
               outOff += var5;
            } else {
               System.arraycopy(var6, 0, out, outOff, var8);
            }
         }

         this.digest.reset();
         return len;
      } else {
         throw new DataLengthException("output buffer too small");
      }
   }
}
